==> hebe-api-1.0.1.tgz: package/src/core/Hebe.ts <==
import { stringify } from "querystring";

export class Hebe {
	private readonly noTokenError = "Use hebe.authenticate() in order to obtain the token";
	private readonly baseUrl = "https://www.hebe.pl";

	public token?: string;
	public username: string;
	public password: string;

	constructor({ username, password }: { username?: string; password?: string } = {}) {
		this.username = username ?? "";
		this.password = password ?? "";
	}

	public authenticate = async ({
		username,
		password,
	}: {
		username?: string;
		password?: string;
	} = {}): Promise<void> => {
		if (username) {
			this.username = username;
		}
		if (password) {
			this.password = password;
		}
		const { csrfToken, dwsidToken } = await this.obtainInitialToken();
		this.token = await this.obtainAuthDwsidToken(dwsidToken, csrfToken);
	};

	private obtainAuthDwsidToken = async (
		initialDwsidToken: string,
		csrfToken: string,
	): Promise<string> => {
		const url = `${this.baseUrl}/on/demandware.store/Sites-Hebe-Site/en_US/Login-LoginForm`;
		const headers = {
			...this.headers,
			Cookie: `dwsid=${initialDwsidToken};`,
		};
		const body = stringify({
			dwfrm_login_username_d0uexrwjfbur: this.username,
			dwfrm_login_password_d0vyhxgwmmwx: this.password,
			csrf_token: csrfToken,
			dwfrm_login_login: "",
			format: "ajax",
		});
		const response = await fetch(url, {
			method: "POST",
			headers,
			body,
		});
		if (response.status !== 200) {
			throw new Error(`Authentication failed, status code: ${response.status}`);
		}
		const { error, status } = JSON.parse(await response.text());
		if (error || status !== "SUCCESS") {
			throw new Error(`Authentication failed: ${error}. Status: ${status}`);
		}
		const dwsidCookie = response.headers
			.getSetCookie()
			.find((cookie) => cookie.includes("dwsid"));
		if (!dwsidCookie) {
			throw new Error("dwsid cookie is not present in the initial token retrieval");
		}
		const dwsidToken = dwsidCookie.split("dwsid=")[1].split(";")[0];
		if (!dwsidToken || typeof dwsidToken !== "string") {
			throw new Error("dwsidToken is not present in the initial token retrieval");
		}
		return dwsidToken;
	};

	private obtainInitialToken = async (): Promise<{ csrfToken: string; dwsidToken: string }> => {
		const response = await fetch(this.baseUrl);
		const dwsidCookie = response.headers
			.getSetCookie()
			.find((cookie) => cookie.includes("dwsid"));
		const txt = await response.text();
		if (!dwsidCookie) {
			throw new Error("dwsid cookie is not present in the initial token retrieval");
		}
		const dwsidToken = dwsidCookie.split("dwsid=")[1].split(";")[0];

		const csrfRaw = txt?.split("window.CSRFToken = ")[1]?.split(";")[0];
		if (!csrfRaw) {
			throw new Error("csrfToken is not present in the initial token retrieval");
		}
		const csrfJson = JSON.parse(csrfRaw);
		const csrfToken = csrfJson?.value;
		if (!csrfToken || typeof csrfToken !== "string") {
			throw new Error("csrfToken is not present in the initial token retrieval");
		}
		return {
			csrfToken,
			dwsidToken,
		};
	};

	private get headers() {
		return {
			"Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
			"X-Requested-With": "XMLHttpRequest",
			Origin: this.baseUrl,
			Referer: `${this.baseUrl}/home?showform=true&targeturl=%2Faccount`,
			...(this.token && {
				Cookie: `dwsid=${this.token}`,
			}),
		};
	}
}

==> hebe-api-1.0.2.tgz: package/src/core/Hebe.ts <==
import { parse } from "node-html-parser";
import { stringify } from "querystring";
import { Order } from ".";

interface AuthenticationParams {
	username?: string;
	password?: string;
}

interface OrdersPagination {
	start?: number;
	maxOrders?: number;
}

export class Hebe {
	private readonly noTokenError = "Use hebe.authenticate() in order to obtain the token";
	private readonly baseUrl = "https://www.hebe.pl";

	public token?: string;
	public username: string;
	public password: string;

	constructor({ username, password }: AuthenticationParams = {}) {
		this.username = username ?? "";
		this.password = password ?? "";
	}

	/**
	 * Obtains `this.token` with optionally specified credentials. If not specified, credentials from constructor are to be used.
	 *
	 * @param authenticationParams - optional, if specified will override set on contructor `this.username` and `this.password`
	 */
	public authenticate = async ({
		username,
		password,
	}: AuthenticationParams = {}): Promise<void> => {
		if (username) {
			this.username = username;
		}
		if (password) {
			this.password = password;
		}
		const { csrfToken, dwsidToken } = await this.obtainInitialToken();
		this.token = await this.obtainAuthDwsidToken(dwsidToken, csrfToken);
	};

	/**
	 * Retrieves users orders. Authenticates if not authenticated
	 *
	 * @param OrdersPagination: optional, if not specified, `maxOrders=100` and `start=0`
	 * @returns a list of Order class
	 */
	public getOrders = async ({ maxOrders, start }: OrdersPagination = {}): Promise<Order[]> => {
		if (!this.token) {
			await this.authenticate();
		}
		if (!maxOrders) {
			maxOrders = 100;
		}
		if (!start) {
			start = 0;
		}

		return await this.obtainOrders(start, maxOrders);
	};

	private obtainOrders = async (
		start: number = 0,
		maxOrders: number = 100,
		orders: Order[] = [],
	): Promise<Order[]> => {
		const url = `${this.baseUrl}/orders?order_status=1&start=${start}`;
		const response = await fetch(url, {
			headers: this.headers,
		});
		if (response.status !== 200) {
			throw new Error(
				`Orders retrieval failed, status code: ${response.status}, url: ${url}`,
			);
		}
		const txt = await response.text();
		if (!txt.includes("orders-detail__section")) {
			return [];
		}
		const root = parse(txt);
		const ordersDetails = root.querySelectorAll(".orders-detail__section");
		orders = orders.concat(
			ordersDetails.map((orderDetails, index) => new Order(orderDetails, start + index)),
		);
		if (ordersDetails.length === 5 && orders.length < maxOrders) {
			await this.obtainOrders(start + 5, maxOrders, orders);
		}
		return orders.slice(0, maxOrders);
	};

	private obtainAuthDwsidToken = async (
		initialDwsidToken: string,
		csrfToken: string,
	): Promise<string> => {
		const url = `${this.baseUrl}/on/demandware.store/Sites-Hebe-Site/en_US/Login-LoginForm`;
		const headers = {
			...this.headers,
			Cookie: `dwsid=${initialDwsidToken};`,
		};
		const body = stringify({
			dwfrm_login_username_d0uexrwjfbur: this.username,
			dwfrm_login_password_d0vyhxgwmmwx: this.password,
			csrf_token: csrfToken,
			dwfrm_login_login: "",
			format: "ajax",
		});
		const response = await fetch(url, {
			method: "POST",
			headers,
			body,
		});
		if (response.status !== 200) {
			throw new Error(`Authentication failed, status code: ${response.status}`);
		}
		const { error, status } = JSON.parse(await response.text());
		if (error || status !== "SUCCESS") {
			throw new Error(`Authentication failed: ${error}. Status: ${status}`);
		}
		const dwsidCookie = response.headers
			.getSetCookie()
			.find((cookie) => cookie.includes("dwsid"));
		if (!dwsidCookie) {
			throw new Error("dwsid cookie is not present in the initial token retrieval");
		}
		const dwsidToken = dwsidCookie.split("dwsid=")[1].split(";")[0];
		if (!dwsidToken || typeof dwsidToken !== "string") {
			throw new Error("dwsidToken is not present in the initial token retrieval");
		}
		return dwsidToken;
	};

	private obtainInitialToken = async (): Promise<{ csrfToken: string; dwsidToken: string }> => {
		const response = await fetch(this.baseUrl);
		const dwsidCookie = response.headers
			.getSetCookie()
			.find((cookie) => cookie.includes("dwsid"));
		const txt = await response.text();
		if (!dwsidCookie) {
			throw new Error("dwsid cookie is not present in the initial token retrieval");
		}
		const dwsidToken = dwsidCookie.split("dwsid=")[1].split(";")[0];

		const csrfRaw = txt?.split("window.CSRFToken = ")[1]?.split(";")[0];
		if (!csrfRaw) {
			throw new Error("csrfToken is not present in the initial token retrieval");
		}
		const csrfJson = JSON.parse(csrfRaw);
		const csrfToken = csrfJson?.value;
		if (!csrfToken || typeof csrfToken !== "string") {
			throw new Error("csrfToken is not present in the initial token retrieval");
		}
		return {
			csrfToken,
			dwsidToken,
		};
	};

	private get headers() {
		return {
			"Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
			"X-Requested-With": "XMLHttpRequest",
			Origin: this.baseUrl,
			Referer: `${this.baseUrl}/home?showform=true&targeturl=%2Faccount`,
			...(this.token && {
				Cookie: `dwsid=${this.token}`,
			}),
		};
	}
}
